<template>
  <div>
    <TableCard :showTitle="false">
      <template slot="form">
        <div class="action-box">
          <div></div>
          <div class="flex">
            <el-button icon="el-icon-plus" size="small" type="primary" @click="showDialog">
              添加项目
            </el-button>
            <!-- <el-button icon="el-icon-upload2" size="small" @click="exportExcel">
              导出
            </el-button> -->
          </div>
        </div>
      </template>
      <template v-slot:table>
        <ZTTable
          :column="columns"
          :height="'25vh'"
          :isSelection="true"
          :table-data="tableData"
          style="margin-top: 18px; padding: 0 15px;"
        >
          <template v-slot:operation="scope">
            <el-button size="small" type="text" @click="deleteData(scope.row)">删除</el-button>
          </template>
        </ZTTable>
        <div class="pagination">
          <div></div>
          <el-pagination
            :page-size="pagination.pageSize"
            :page-sizes="[10, 20, 30, 40]"
            :total="pagination.total"
            layout="total, sizes, prev, pager, next, jumper"
            @current-change="handleCurrent"
            @size-change="handleSize"
          >
          </el-pagination>
        </div>
      </template>
    </TableCard>
    <AddProject ref="AddProjectRef" @submit="fetchData,$emit('submit')"/>
  </div>
</template>

<script>
import TableCard from '@/components/caorui/TableCard/index.vue';
import ZTTable from '@/components/caorui/ZTTable/index.vue';
import Edit from "./components/Edit.vue"
import AddProject from './components/AddProject.vue';
import {
  deleteProcurementSuppliesExpends,
  procurementSuppliesExpendsList,
  procurementSuppliesList
} from "../../../assets/api/api";
import axios from "axios";

export default {
  components: {
    TableCard, ZTTable, Edit, AddProject
  },
  data() {
    return {
      columns: [
        // {
        //   label: "编号"
        // },
        {
          label: "项目名称",
          prop: "listName"
        },
        {
          label: "消耗数量",
          prop: "amount"
        },
        {
          label: "录入人",
          prop: "enterUserName"
        },
        {
          label: "最近更新人",
          prop: "updateUserName"
        },
        {
          label: "最近更新日期",
          prop: "updateTime"
        },
        {
          label: "操作",
          dataType: "slot",
          slot: "operation"
        }
      ],
      tableData: [],
      pagination: {
        current: 1,
        pageSize: 20,
        total: 0
      },
      listId: 0,
      row: undefined
    }
  },
  mounted() {
    this.fetchData()
  },
  methods: {
    fetchListId(row) {
      if(row) {
        this.listId = row.id
        this.row = row
      }
      this.fetchData()
    },
    async fetchData() {
      if (this.listId === 0) return
      const res = await axios({
        method: 'get',
        url: `${procurementSuppliesExpendsList}/${this.listId}`,
        params: {
          // page: this.pagination.current,
          // pageSize: this.pagination.pageSize,
        }
      })
      if (res.code === 200) {
        this.tableData = res.data
      }
    },
    showDialog() {
      this.$refs.AddProjectRef.openDialog(this.row);
    },
    deleteData(row) {
      this.$axios.post(deleteProcurementSuppliesExpends, row, {
              headers: {
                'Content-Type': 'application/json'
              }
            }).then(res => {
        if (res.code === 200) {
          this.$message.success('删除成功')
          this.$emit('submit')
          this.fetchData()
        }
      })
    },
    handleCurrent() {
    },
    handleSize() {
    },
    exportExcel() {
    }
  }
}
</script>

<style scoped>
.flex {
  display: flex;
}

.action-box {
  width: 100%;
  padding-top: 10px;
  display: flex;
  align-items: center;
  justify-content: space-between;
}

.pagination {
  padding-top: 15px;
  padding-right: 10px;
  display: flex;
  justify-content: space-between
}
</style>
